#[non_exhaustive]pub enum DeviceState {
Unspecified,
Device,
Recovery,
Rescue,
Sideload,
Missing,
Offline,
Unauthorized,
Authorizing,
Connecting,
UnknownValue(UnknownValue),
}Expand description
The state displayed with the ADB Device when running “adb devices”
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The device state is unknown.
Device
The ADB device is in the “device” status.
Recovery
The ADB device is in the “recovery” status.
Rescue
The ADB device is in the “rescue” status.
Sideload
The ADB device is in the “sideload” status.
Missing
The ADB device is in the “missing” status.
Offline
The ADB device is in the “offline” status.
The ADB device is in the “unauthorized” status.
Authorizing
The ADB device is in the “authorizing” status.
Connecting
The ADB device is in the “connecting” status.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DeviceState::value or DeviceState::name.
Implementations